==> blink-components-0.4.4.tgz: package/.storybook/office3/home.js <==
// @flow

import React from 'react'
import { ThemeProvider } from 'react-css-themr'
import cn from 'classnames'
import Link from 'components/Link'
import Icon from 'components/Icon'
import Template from 'components/Template'
import Section from 'components/Section'
import Carousel from 'components/Carousel'
import Form from 'components/Form'
import SimpleMap from 'components/SimpleMap'
import CustomerReviewList from 'components/CustomerReviewList'
import CountUp from 'components/CountUp'
import theme from './theme.yml'

import {
  navItems,
  intro,
  features,
  customerReviews,
  services,
  languages,
  footer,
  map,
  form,
  copyright,
} from '../../sample-data/office.yml'

const Home = () => (
  <ThemeProvider theme={theme}>
    <Template
      theme={theme}
      items={navItems}
      languages={languages}
      footer={footer}
      copyright={copyright}
    >
      <Carousel
        className="w-100"
        imagesToShow={1}
        items={services}
        renderItem={({ image, title, description, actions }) => (
          <div
            className="vh-100 h-auto-ns aspect-ratio--4x3-m aspect-ratio--16x9-l cover"
            key={image}
            style={{
              backgroundImage: `url(${image})`,
            }}
          >
            <div className="aspect-ratio--object flex items-center justify-center bg-black-50">
              <div className="tc">
                <h3 className="white-80 f2 fw9 f1-l">{title}</h3>
              <div className="white-80 f4 mw7 mb3 fw4">{description}</div>
              <div className="flex justify-center pt3">
                  {actions.map(({ to, label, className }) => (
                    <Link
                      className={cn('pointer dib w4 pa2 mh2', className)}
                      to={to}
                    >
                      {label}
                    </Link>
                  ))}
                </div>
              </div>
            </div>
          </div>
        )}
      />
      {/* Side by Side Intro */}
      <div data-component="Intro" className="flex flex-wrap">
        <div className="w-100 w-40-ns">
          <img src={intro.image} alt={intro.title} />
        </div>
        <div className="w-100 w-60-ns pa4 pa5-l">
          <div className="ttu f2 f1-ns fw9 ph3">{intro.title}</div>
        <div className="ph3 f3-s b f3-ns">{intro.subtitle}</div>
      <div className="w4 tl ph3 pv2">
        <div className="bb bw2 green"></div>
        </div>
        <div className="ph3 pv3">{intro.description}</div>
          <div className="flex flex-wrap">
            {intro.items.map(item => (
              <div key={item.label} className="w-100 flex">
                <div className="w-25 tr pr2 mb2">
                  <CountUp
                    className="f1 fw9 green"
                    start={0}
                    end={item.value}
                  />
                </div>
                <div className="w-75">
                  <div className="pl3 f4 b">{item.label}</div>
                  <div className="pl2">{item.title}</div>
                <div className="pl3">{item.description}</div>
                </div>
              </div>
            ))}
          </div>
        </div>
      </div>
      {/* Features */}
      <Section
        title={features.title}
        subtitle={features.subtitle}
        showHr
        theme={{
          root: 'bg-near-white ph3 pv4',
          title: 'f2 f1-ns tc ttu fw9 pv3',
          body: 'flex flex-wrap',
          hr: 'w4 bb bw2 green center',
        }}
      >
        {features.items.map(item => (
          <div key={item.label} className="w-50 w-auto-ns flex-auto-ns tc fw9 pt5 pb4">
            <div>
              <Icon name={item.icon} className="f2 green pb4 pb4" />
            </div>
            <div>{item.label}</div>
          </div>
        ))}
      </Section>
      <Section
        title={customerReviews.title}
        subtitle={customerReviews.subtitle}
        theme={{
          root: '',
          title: 'f3 f2-ns tc ttu fw9 pv3',
          subtitle: 'tc ph3 f5 f4-ns b',
          body: 'flex ph3 ph5-ns',
        }}
      >
        <CustomerReviewList
          className="w-100"
          data={customerReviews.items}
        />
      </Section>
      <Section
        className="w-100"
        title={map.title}
        subtitle={map.subtitle}
        theme={{
          title: 'ttu f3 fw9 ph3 tl pl3',
          subtitle: 'ph3 f4 b tl',
          body: 'flex flex-wrap',
        }}
      >
        <div className="w-100 w-50-ns order-2">
          <div className="relative aspect-ratio--4x3">
            <div className="aspect-ratio--object">
              <SimpleMap
                markers={[{
                  key: 'TCH',
                  position: map.center,
                  defaultAnimation: 2,
                }]}
                center={map.center}
              />
            </div>
          </div>
        </div>
        <div className="w-100 w-50-ns pa3 pa4-ns order-1 bg-washed-green">
          <div className="tc">
            <h3 className="f3 fw9 ph3 pb3 pb4-ns">{form.title}</h3>
          <div className="f5">{form.subtitle}</div>
          </div>
          <Form
            fields={form.fields}
            submitText="Đặt chỗ"
          />
        </div>
      </Section>
    </Template>
  </ThemeProvider>
)

export default Home

==> blink-components-0.10.5.tgz: package/.storybook/office3/home.js <==
// @flow

import React from 'react'
import { ThemeProvider } from 'react-css-themr'
import cn from 'classnames'
import Link from 'components/Link'
import Icon from 'components/Icon'
import Template from 'components/Template'
import Section from 'components/Section'
import Carousel from 'components/Carousel'
import Form from 'components/Form'
import SimpleMap from 'components/SimpleMap'
import CustomerReviewList from 'components/CustomerReviewList'
import CountUp from 'components/CountUp'
import theme from './theme.yml'

import {
  navItems,
  intro,
  features,
  customerReviews,
  services,
  languages,
  footer,
  map,
  form,
  copyright,
} from '../../sample-data/office.yml'

const Home = () => (
  <ThemeProvider theme={theme}>
    <Template
      theme={theme}
      items={navItems}
      languages={languages}
      footer={footer}
      copyright={copyright}
    >
      <Carousel
        className="w-100 mh-50"
        imagesToShow={1}
        items={services}
        renderItem={({ image, title, description, actions }) => (
          <div
            className="vh-100 vh-75-ns cover"
            key={image}
            style={{
              backgroundImage: `url(${image})`,
            }}
          >
            <div className="aspect-ratio--object flex items-center justify-center bg-black-50">
              <div className="tc">
                <h3 className="white-80 f2 fw9 f1-l">{title}</h3>
                <div className="white-80 f4 mw7 mb3 fw4">{description}</div>
                <div className="flex justify-center pt3">
                  {actions.map(({ to, label, className }) => (
                    <Link
                      className={cn('pointer dib w4 pa2 mh2', className)}
                      to={to}
                    >
                      {label}
                    </Link>
                  ))}
                </div>
              </div>
            </div>
          </div>
        )}
      />
      {/* Side by Side Intro */}
      <div data-component="Intro" className="flex flex-wrap">
        <div className="w-100 w-40-ns">
          <img src={intro.image} alt={intro.title} />
        </div>
        <div className="w-100 w-60-ns pa4 pa5-l">
          <div className="ttu f2 f1-ns fw9 ph3">{intro.title}</div>
          <div className="ph3 f3-s b f3-ns">{intro.subtitle}</div>
          <div className="w4 tl ph3 pv2">
            <div className="bb bw2 green" />
          </div>
          <div className="ph3 pv3">{intro.description}</div>
          <div className="flex flex-wrap">
            {intro.items.map(item => (
              <div key={item.label} className="w-100 flex">
                <div className="w-25 tr pr2 mb2">
                  <CountUp
                    className="f1 fw9 green"
                    start={0}
                    end={item.value}
                  />
                </div>
                <div className="w-75">
                  <div className="pl3 f4 b">{item.label}</div>
                  <div className="pl2">{item.title}</div>
                  <div className="pl3">{item.description}</div>
                </div>
              </div>
            ))}
          </div>
        </div>
      </div>
      {/* Features */}
      <Section
        title={features.title}
        subtitle={features.subtitle}
        showHr
        theme={{
          root: 'bg-near-white ph3 pv4',
          title: 'f2 f1-ns tc ttu fw9 pv3',
          body: 'flex flex-wrap',
          hr: 'w4 bb bw2 green center',
        }}
      >
        {features.items.map(item => (
          <div key={item.label} className="w-50 w-auto-ns flex-auto-ns tc fw9 pt5 pb4">
            <div>
              <Icon name={item.icon} className="f2 green pb4 pb4" />
            </div>
            <div>{item.label}</div>
          </div>
        ))}
      </Section>
      <Section
        title={customerReviews.title}
        subtitle={customerReviews.subtitle}
        theme={{
          root: '',
          title: 'f3 f2-ns tc ttu fw9 pv3',
          subtitle: 'tc ph3 f5 f4-ns b',
          body: 'flex ph3 ph5-ns',
        }}
      >
        <CustomerReviewList
          className="w-100"
          data={customerReviews.items}
        />
      </Section>
      <Section
        className="w-100"
        title={map.title}
        subtitle={map.subtitle}
        theme={{
          title: 'ttu f3 fw9 ph3 tl pl3',
          subtitle: 'ph3 f4 b tl',
          body: 'flex flex-wrap',
        }}
      >
        <div className="w-100 w-50-ns order-2">
          <div className="relative aspect-ratio--4x3">
            <div className="aspect-ratio--object">
              <SimpleMap
                markers={[{
                  key: 'TCH',
                  position: map.center,
                  defaultAnimation: 2,
                }]}
                center={map.center}
              />
            </div>
          </div>
        </div>
        <div className="w-100 w-50-ns pa3 pa4-ns order-1 bg-washed-green">
          <div className="tc">
            <h3 className="f3 fw9 ph3 pb3 pb4-ns">{form.title}</h3>
            <div className="f5">{form.subtitle}</div>
          </div>
          <Form
            fields={form.fields}
            submitText="Đặt chỗ"
          />
        </div>
      </Section>
    </Template>
  </ThemeProvider>
)

export default Home
